@@ -1,8 +1,8 @@
-// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2022 - 2023 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: LGPL-3.0-or-later
 
-#include "dtkwidget/util/dregionmonitor.h"
+#include "dregionmonitor.h"
 #include "private/dregionmonitor_p.h"
 
 DWIDGET_BEGIN_NAMESPACE
