@@ -1,9 +1,11 @@
-// SPDX-FileCopyrightText: 2017 - 2022 UnionTech Software Technology Co., Ltd.
+// SPDX-FileCopyrightText: 2017 - 2023 UnionTech Software Technology Co., Ltd.
 //
 // SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "daboutdialog.h"
+#include "dfeaturedisplaydialog.h"
 #include "private/daboutdialog_p.h"
+#include "private/dlicensedialog_p.h"
 
 #include <dwidgetutil.h>
 #include <DSysInfo>
@@ -61,7 +63,7 @@ void DAboutDialogPrivate::init()
 {
     D_Q(DAboutDialog);
 
-    q->setMinimumWidth(360);
+    q->setMaximumWidth(540);
 
     // overwrite default info if distribution config file existed.
     loadDistributionInfo();
@@ -87,13 +89,8 @@ void DAboutDialogPrivate::init()
     websiteLabel->setOpenExternalLinks(false);
     updateWebsiteLabel();
 
-    acknowledgementLabel = new QLabel();
-    acknowledgementLabel->setObjectName("AcknowledgementLabel");
-    acknowledgementLabel->setContextMenuPolicy(Qt::NoContextMenu);
-    acknowledgementLabel->setOpenExternalLinks(false);
-    updateAcknowledgementLabel();
-
     descriptionLabel = new QLabel();
+    descriptionLabel->setFixedWidth(280);
     descriptionLabel->setObjectName("DescriptionLabel");
     descriptionLabel->setAlignment(Qt::AlignLeft);
     descriptionLabel->setWordWrap(true);
@@ -101,6 +98,7 @@ void DAboutDialogPrivate::init()
     fontManager->bind(descriptionLabel, DFontSizeManager::T8, QFont::DemiBold);
 
     licenseLabel = new QLabel();
+    licenseLabel->setFixedWidth(180);
     licenseLabel->setObjectName("LicenseLabel");
     licenseLabel->setAlignment(Qt::AlignHCenter);
     licenseLabel->setWordWrap(true);
@@ -113,6 +111,7 @@ void DAboutDialogPrivate::init()
     featureLabel = new QLabel(websiteLinkTemplate.arg(websiteLink).arg(QObject::tr("Features")));
     featureLabel->setContextMenuPolicy(Qt::NoContextMenu);
     featureLabel->setOpenExternalLinks(false);
+    featureLabel->setVisible(!qApp->featureDisplayDialog()->isEmpty());
     redPointLabel = new DRedPointLabel();
     redPointLabel->setFixedSize(10, 10);
     QHBoxLayout *vFeatureLayout =  new QHBoxLayout;
@@ -125,27 +124,43 @@ void DAboutDialogPrivate::init()
     fontManager->bind(homePageTipLabel, DFontSizeManager::T10, QFont::Normal);
     QLabel *descriptionTipLabel = new QLabel(QObject::tr("Description"));
     fontManager->bind(descriptionTipLabel, DFontSizeManager::T10, QFont::Normal);
+    acknowledgementTipLabel = new QLabel(QObject::tr("Acknowledgements"));
+    fontManager->bind(acknowledgementTipLabel, DFontSizeManager::T10, QFont::Normal);
+    acknowledgementLabel = new QLabel(QObject::tr("Sincerely appreciate the open-source software used."));
+    acknowledgementLabel->setFixedWidth(280);
+    acknowledgementLabel->setWordWrap(true);
+    acknowledgementLabel->setContextMenuPolicy(Qt::NoContextMenu);
+    acknowledgementLabel->setOpenExternalLinks(false);
+    fontManager->bind(acknowledgementLabel, DFontSizeManager::T8, QFont::DemiBold);
+
+    licenseDialog = new DLicenseDialog(q);
+    licenseDialog->load();
+    QString ack = QObject::tr("Sincerely appreciate the open-source software used.");
+    if (licenseDialog->isValid()) {
+        QString tmp = QObject::tr("open-source software");
+        ack = ack.replace(tmp, websiteLinkTemplate.arg(websiteLink).arg(tmp));
+    }
+    acknowledgementLabel->setText(ack);
 
     q->connect(websiteLabel, SIGNAL(linkActivated(QString)), q, SLOT(_q_onLinkActivated(QString)));
     q->connect(featureLabel, SIGNAL(linkActivated(QString)), q, SLOT(_q_onFeatureActivated(QString)));
-    q->connect(acknowledgementLabel, SIGNAL(linkActivated(QString)), q, SLOT(_q_onLinkActivated(QString)));
     q->connect(descriptionLabel, SIGNAL(linkActivated(QString)), q, SLOT(_q_onLinkActivated(QString)));
     q->connect(licenseLabel, SIGNAL(linkActivated(QString)), q, SLOT(_q_onLinkActivated(QString)));
+    q->connect(acknowledgementLabel, SIGNAL(linkActivated(QString)), q, SLOT(_q_onLicenseActivated(QString)));
 
     QVBoxLayout *leftVLayout = new QVBoxLayout;
-    leftVLayout->setContentsMargins(30, 3, 0, 20);
+    leftVLayout->setContentsMargins(10, 3, 0, 10);
     leftVLayout->setSpacing(0);
     leftVLayout->addWidget(logoLabel, 0, Qt::AlignCenter);
     leftVLayout->addSpacing(8);
     leftVLayout->addWidget(productNameLabel, 0, Qt::AlignCenter);
-    leftVLayout->addSpacing(31);
+    leftVLayout->addStretch(0);
     leftVLayout->addWidget(companyLogoLabel, 0, Qt::AlignCenter);
     leftVLayout->addSpacing(3);
     leftVLayout->addWidget(licenseLabel, 0, Qt::AlignHCenter);
-    leftVLayout->addStretch(0);
 
     QVBoxLayout *rightVLayout = new QVBoxLayout;
-    rightVLayout->setContentsMargins(0, 3, 30, 20);
+    rightVLayout->setContentsMargins(0, 3, 20, 10);
     rightVLayout->setSpacing(0);
     rightVLayout->addWidget(versionTipLabel, 0, Qt::AlignLeft);
     rightVLayout->addWidget(versionLabel, 0, Qt::AlignLeft);
@@ -156,12 +171,16 @@ void DAboutDialogPrivate::init()
     rightVLayout->addSpacing(10);
     rightVLayout->addWidget(descriptionTipLabel, 0, Qt::AlignLeft);
     rightVLayout->addWidget(descriptionLabel, 0, Qt::AlignLeft);
+    rightVLayout->addSpacing(10);
+    rightVLayout->addWidget(acknowledgementTipLabel, 0, Qt::AlignLeft);
+    rightVLayout->addWidget(acknowledgementLabel, 0, Qt::AlignLeft);
     rightVLayout->addStretch(0);
 
     QHBoxLayout *mainLayout = new QHBoxLayout;
     mainLayout->setSpacing(0);
     mainLayout->setMargin(0);
     mainLayout->addLayout(leftVLayout);
+    mainLayout->addSpacing(29);
     mainLayout->addLayout(rightVLayout);
 
     QScrollArea *mainScrollArea = new QScrollArea;
@@ -198,12 +217,6 @@ void DAboutDialogPrivate::updateWebsiteLabel()
     websiteLabel->setText(websiteText);
 }
 
-void DAboutDialogPrivate::updateAcknowledgementLabel()
-{
-    QString acknowledgementText = QString(websiteLinkTemplate).arg(acknowledgementLink).arg(QApplication::translate("DAboutDialog", "Acknowledgements"));
-    acknowledgementLabel->setText(acknowledgementText);
-}
-
 void DAboutDialogPrivate::_q_onLinkActivated(const QString &link)
 {
     DGUI_NAMESPACE::DGuiApplicationHelper::openUrl(link);
@@ -220,6 +233,11 @@ void DAboutDialogPrivate::_q_onFeatureActivated(const QString &)
     Q_EMIT q->featureActivated();
 }
 
+void DAboutDialogPrivate::_q_onLicenseActivated(const QString &)
+{
+    licenseDialog->show();
+}
+
 QPixmap DAboutDialogPrivate::loadPixmap(const QString &file)
 {
     D_Q(DAboutDialog);
@@ -363,9 +381,7 @@ QString DAboutDialog::websiteLink() const
  */
 QString DAboutDialog::acknowledgementLink() const
 {
-    D_DC(DAboutDialog);
-
-    return d->acknowledgementLink;
+    return QString();
 }
 
 /*!
@@ -483,12 +499,8 @@ void DAboutDialog::setWebsiteLink(const QString &websiteLink)
 @~english
   @brief This function is used to set the specified ACKNOWLEDGEMENTLINK Link
  */
-void DAboutDialog::setAcknowledgementLink(const QString &acknowledgementLink)
+void DAboutDialog::setAcknowledgementLink(const QString &)
 {
-    D_D(DAboutDialog);
-
-    d->acknowledgementLink = acknowledgementLink;
-    d->updateAcknowledgementLabel();
 }
 
 /*!
@@ -499,7 +511,7 @@ void DAboutDialog::setAcknowledgementVisible(bool visible)
 {
     Q_UNUSED(visible)
     D_D(DAboutDialog);
-//    d->acknowledgementLabel->setVisible(visible);
+    d->acknowledgementLabel->setVisible(visible);
 }
 
 /*!
