@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2020 ~ 2021 Deepin Technology Co., Ltd.
- *
- * Author:     ck <chenke@uniontech.com>
- *
- * Maintainer: ck <chenke@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2020 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "DStyle"
 #include "dalertcontrol.h"
@@ -98,14 +81,14 @@ DAlertControl::~DAlertControl()
 }
 
 /*!
- * \~chinese \brief DAlertControl::setAlert设置是否开启警告模式
- * \~chinese \row 警告模式，开启警告模式，target将显示警告颜色
- * \~chinese \param isAlert是否开启警告模式
+@~english
+  \brief DAlertControl::setAlertSet whether to turn on the warning modeOpen the warning mode, Target will display the warning color
+  \a isAlert Whether to turn on a warning mode
  */
 void DAlertControl::setAlert(bool isAlert)
 {
     D_D(DAlertControl);
-    if (isAlert == d->isAlert) {
+    if (isAlert == d->isAlert || !d->target) {
         return;
     }
 
@@ -125,7 +108,8 @@ void DAlertControl::setAlert(bool isAlert)
 }
 
 /*!
- * \~chinese \brief DAlertControl::alert返回当前是否处于警告模式
+@~english
+  \brief DAlertControl::alertBack to whether it is currently in a warning mode
  */
 bool DAlertControl::isAlert() const
 {
@@ -135,8 +119,9 @@ bool DAlertControl::isAlert() const
 }
 
 /*!
- * \~chinese \brief DAlertControl::defaultAlertColor返回默认告警颜色
- * \~chinese \row \note 默认颜色和原 DLineEdit 一致
+@~english
+  \brief DAlertControl::defaultAlertColorBack to the default alarm color
+  \note The default color is consistent with the original DLINEEDIT
  */
 QColor DAlertControl::defaultAlertColor() const
 {
@@ -144,8 +129,9 @@ QColor DAlertControl::defaultAlertColor() const
 }
 
 /*!
- * \~chinese \brief DAlertControl::setAlertColor 设置告警颜色
- * \~chinese \param c 告警颜色
+@~english
+  \brief DAlertControl::setAlertColor Set alarm color
+  \a c Alarm color
  */
 void DAlertControl::setAlertColor(QColor c)
 {
@@ -161,7 +147,8 @@ void DAlertControl::setAlertColor(QColor c)
 }
 
 /*!
- * \~chinese \brief DAlertControl::alertColor 返回当前告警颜色
+@~english
+  \brief DAlertControl::alertColor Return to the current alarm color
  */
 QColor DAlertControl::alertColor() const
 {
@@ -170,10 +157,10 @@ QColor DAlertControl::alertColor() const
 }
 
 /*!
- * \~chinese \brief DAlertControl::setMessageAlignment指定对齐方式
- * \~chinese \row 现只支持左，右，居中， 默认左对齐.
- * \~chinese \row \note 参数为其他时，默认左对齐
- * \~chinese \param alignment消息对齐方式
+@~english
+  \brief DAlertControl::setMessageAlignmentSpecify the alignment method Now only support the left, right, center, default left
+  \note When the parameters are other, the default left
+  \a alignment 消息对齐方式
  */
 void DAlertControl::setMessageAlignment(Qt::Alignment alignment)
 {
@@ -182,7 +169,8 @@ void DAlertControl::setMessageAlignment(Qt::Alignment alignment)
 }
 
 /*!
- * \~chinese \brief DAlertControl::messageAlignment 返回当前告警 tooltips 对齐方式
+@~english
+  \brief DAlertControl::messageAlignment Return to the current alarm Tooltips alignment method
  */
 Qt::Alignment DAlertControl::messageAlignment() const
 {
@@ -191,12 +179,12 @@ Qt::Alignment DAlertControl::messageAlignment() const
 }
 
 /*!
- * \~chinese \brief DAlertControl::showAlertMessage显示警告消息
- * \~chinese \row 显示指定的文本消息，超过指定时间后警告消息消失.
- * \~chinese \row \note 时间参数为-1时，警告消息将一直存在
- * \~chinese \param text警告的文本
- * \~chinese \param duration显示的时间长度，单位毫秒
- * \~chinese \param parent tooltip跟随
+@~english
+  \brief DAlertControl::showAlertMessage Display warning message
+ Display the specified text message, exceeding the warning message disappearing after the specified time.
+  \note When the time parameter is -1, the warning message will always exist
+  \a text Warning text
+  \a duration Display time length, unit milliseconds
  */
 void DAlertControl::showAlertMessage(const QString &text, int duration)
 {
@@ -204,16 +192,20 @@ void DAlertControl::showAlertMessage(const QString &text, int duration)
 }
 
 /*!
- * \~chinese \brief DAlertControl::showAlertMessage显示警告消息
- * \~chinese \row 显示指定的文本消息，超过指定时间后警告消息消失.
- * \~chinese \row \note 时间参数为-1时，警告消息将一直存在
- * \~chinese \param text警告的文本
- * \~chinese \param follow指定文本消息跟随的对象
- * \~chinese \param duration显示的时间长度，单位毫秒
+@~english
+  \brief DAlertControl::showAlertMessage Display warning message.
+
+  Display the specified text message, exceeding the warning message disappearing after the specified time
+  \note When the time parameter is -1, the warning message will always exist
+  \a text Warning text
+  \a follow Specify the object of the text message
+  \a duration Display time length, unit milliseconds
  */
 void DAlertControl::showAlertMessage(const QString &text, QWidget *follower, int duration)
 {
     D_D(DAlertControl);
+    if (!d->target)
+        return;
 
     if (!d->tooltip) {
         d->tooltip = new DToolTip(text);
@@ -230,20 +222,21 @@ void DAlertControl::showAlertMessage(const QString &text, QWidget *follower, int
     }
 
     if (follower) {
-        d->frame->setParent(follower->parentWidget());
+        d->frame->setParent(follower->topLevelWidget());
         d->follower = follower;
-        //installEventFilter(d->follower);
         d->follower->installEventFilter(this);
     } else {
-        d->frame->setParent(d->target->parentWidget());
+        d->frame->setParent(d->target->topLevelWidget());
         d->follower = d->target;
         d->follower->installEventFilter(this);
     }
+    d->follower->topLevelWidget()->installEventFilter(this);
 
     d->tooltip->setText(text);
     if (d->frame->parent()) {
         d->updateTooltipPos();
-        d->frame->show();
+        // 如果 target 都隐藏了,显示警告消息毫无意义，只会让人困惑
+        d->frame->setVisible(d->target->isVisibleTo(d->target->topLevelWidget()));
         d->frame->adjustSize();
         d->frame->raise();
     }
@@ -256,7 +249,8 @@ void DAlertControl::showAlertMessage(const QString &text, QWidget *follower, int
 }
 
 /*!
- * \~chinese \brief DAlertControl:: hideAlertMessage隐藏警告消息框
+@~english
+  \brief DAlertControl:: hideAlertMessage隐藏警告消息框
  */
 void DAlertControl::hideAlertMessage()
 {
@@ -282,9 +276,20 @@ DAlertControl::DAlertControl(DAlertControlPrivate &d, QObject *parent)
 bool DAlertControl::eventFilter(QObject *watched, QEvent *event)
 {
     Q_D(DAlertControl);
-    if (watched == d->follower && (event->type() == QEvent::Move ||
-                                   event->type() == QEvent::Resize)) {
-        d->updateTooltipPos();
+    if (watched == d->follower) {
+        if (event->type() == QEvent::Move || event->type() == QEvent::Resize)
+            d->updateTooltipPos();
+
+        if (event->type() == QEvent::Hide || event->type() == QEvent::HideToParent)
+            hideAlertMessage();
+    }
+
+    if (d->follower && watched == d->follower->topLevelWidget()) {
+        if (event->type() == QEvent::HoverMove || event->type() == QEvent::UpdateRequest)
+            d->updateTooltipPos();
+
+        if (d->timer.isActive())
+            d->frame->setVisible(!d->follower->visibleRegion().isNull());
     }
     return QObject::eventFilter(watched, event);
 }
