@@ -1111,7 +1111,12 @@ DFeatureDisplayDialog *DApplication::featureDisplayDialog()
 {
     D_D(DApplication);
     if (d->featureDisplayDialog == nullptr) {
-        d->featureDisplayDialog = new DFeatureDisplayDialog(activeWindow());
+        d->featureDisplayDialog = new DFeatureDisplayDialog();
+        connect(this, &DApplication::aboutToQuit, this, [this]{
+            D_D(DApplication);
+            d->featureDisplayDialog->deleteLater();
+            d->featureDisplayDialog = nullptr;
+        });
     }
     return d->featureDisplayDialog;
 }
@@ -1393,7 +1398,7 @@ void DApplication::handleAboutAction()
     DAboutDialog *aboutDialog = new DAboutDialog(activeWindow());
     aboutDialog->setProductName(productName());
     aboutDialog->setProductIcon(productIcon());
-    aboutDialog->setVersion(translate("DAboutDialog", "Version: %1").arg(applicationVersion()));
+    aboutDialog->setVersion(applicationVersion());
     aboutDialog->setDescription(applicationDescription());
 
     if (!applicationLicense().isEmpty()) {
