@@ -195,6 +195,25 @@ public:
         return DStyle::viewItemSize(style, &item, Qt::DisplayRole);
     }
 
+    // get rect in AlignVCenter layout for text.
+    static QRect textAndTextActionsLayout(const QRect &textRect, const QStyle *style, const QStyleOptionViewItem &option, const QModelIndex &index)
+    {
+        QStyleOptionViewItem opt = option;
+        opt.displayAlignment |= Qt::AlignVCenter;
+        QSize size;
+
+        if (!opt.text.isEmpty())
+            size = DStyle::viewItemSize(style, &opt, Qt::DisplayRole);
+
+        for (const DViewItemAction *action : qvariantToActionList(index.data(Dtk::TextActionListRole))) {
+            const QSize &action_size = displayActionSize(action, style, opt);
+            size.setWidth(qMax(size.width(), action_size.width()));
+            size.setHeight(size.height() + action_size.height());
+        }
+
+        return QStyle::alignedRect(opt.direction , opt.displayAlignment, size, textRect);
+    }
+
     static QList<QRect> doActionsLayout(QRect base, const DViewItemActionList &list, Qt::Orientation orientation,
                                         Qt::LayoutDirection direction, const QSize &fallbackIconSize, QSize *bounding)
     {
@@ -1015,7 +1034,12 @@ void DStyledItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &o
             opt.displayAlignment &= ~Qt::AlignVCenter;
             opt.displayAlignment &= ~Qt::AlignBottom;
 
-            QRect bounding = DStyle::viewItemDrawText(style, painter, &opt, textRect);
+            QRect textRectbounding = d->textAndTextActionsLayout(textRect, style, opt, index);
+
+            QRect bounding(textRectbounding.topLeft(), QSize());
+            if (!opt.text.isEmpty()) {
+                bounding = DStyle::viewItemDrawText(style, painter, &opt, textRectbounding);
+            }
 
             // draw action text
             for (const DViewItemAction *action : text_action_list) {
@@ -1247,7 +1271,8 @@ void DStyledItemDelegate::setBackgroundType(DStyledItemDelegate::BackgroundType
         }
 
         int frame_margin = style->pixelMetric(static_cast<QStyle::PixelMetric>(DStyle::PM_FrameRadius));
-        d->margins += DSizeModeHelper::element(frame_margin / 2, frame_margin);
+        int left_right_margin = style->pixelMetric(static_cast<QStyle::PixelMetric>(DStyle::PM_ContentsMargins));
+        d->margins += QMargins(left_right_margin, frame_margin, left_right_margin, frame_margin);
     }
 }
 
@@ -1404,7 +1429,8 @@ bool DStyledItemDelegate::eventFilter(QObject *object, QEvent *event)
                 break;
 
             int frame_margin = DStyle::pixelMetric(view->style(), DStyle::PM_FrameRadius);
-            d->margins = QMargins() + DSizeModeHelper::element(frame_margin / 2, frame_margin);
+            int left_right_margin = DStyle::pixelMetric(view->style(), DStyle::PM_ContentsMargins);
+            d->margins = QMargins(left_right_margin, frame_margin, left_right_margin, frame_margin);
 
             // relayout to calculate size.
             view->doItemsLayout();
@@ -1416,7 +1442,11 @@ bool DStyledItemDelegate::eventFilter(QObject *object, QEvent *event)
 
         if (event->type() == QEvent::Paint) {
             D_D(DStyledItemDelegate);
-            if (d->readyRecordVisibleWidgetOfCurrentFrame()) {
+            const QPaintEvent *pe = static_cast<QPaintEvent *>(event);
+            // We only hide widgets when updating all area, it maybe also to be paint when hover,
+            // and it's area is a specific part.
+            if (pe->rect() == view->viewport()->rect() &&
+                d->readyRecordVisibleWidgetOfCurrentFrame()) {
                 auto updateEvent = new QEvent(UpdateWidgetVisibleEvent);
                 qApp->postEvent(view->viewport(), updateEvent);
             }
