@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2017 ~ 2017 Deepin Technology Co., Ltd.
- *
- * Author:     zccrs <zccrs@live.com>
- *
- * Maintainer: zccrs <zhangjide@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2017 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #define private public
 #include <QFont>
@@ -35,6 +18,10 @@
 
 #include <cmath>
 
+QT_BEGIN_NAMESPACE
+extern bool qt_is_gui_used;
+QT_END_NAMESPACE
+
 DWIDGET_BEGIN_NAMESPACE
 
 /*!
@@ -119,6 +106,41 @@ void DStyleOption::init(const QWidget *widget)
   \a widget
   \sa Dtk::Widget::DSuggestButton
  */
+DStyleOptionButton::DStyleOptionButton()
+    : QStyleOptionButton ()
+    , DStyleOption ()
+{
+}
+
+/*!
+ * @brief DStyleOptionButton::DStyleOptionButton Custom copy constructor
+ * @param other Source object
+ */
+DStyleOptionButton::DStyleOptionButton(const DStyleOptionButton &other)
+    : QStyleOptionButton (other)
+    , DStyleOption (other)
+{
+    // `dciIcon` broke abi, so we need to distinguish weather `other` has dciIcon.
+    if (other.features & DStyleOptionButton::HasDciIcon)
+        dciIcon = other.dciIcon;
+}
+
+/*!
+ * @brief DStyleOptionButton::operator = Custom assignment constructor
+ * @param other Source obejct
+ * @return
+ */
+DStyleOptionButton &DStyleOptionButton::operator=(const DStyleOptionButton &other)
+{
+    // Set the value of the parent class member variable.
+    this->QStyleOptionButton::operator=(other);
+    this->DStyleOption::operator=(other);
+
+    if (other.features & DStyleOptionButton::HasDciIcon)
+        dciIcon = other.dciIcon;
+    return *this;
+}
+
 void DStyleOptionButton::init(const QWidget *widget)
 {
     DStyleOption::init(widget);
@@ -336,12 +358,26 @@ const QFont DFontSizeManager::get(DFontSizeManager::SizeType type, int weight, c
     return font;
 }
 
+static int d_defaultDpi()
+{
+    if (QCoreApplication::instance()->testAttribute(Qt::AA_Use96Dpi))
+        return 96;
+
+    if (!qt_is_gui_used)
+        return 75;
+
+    //PI has not been initialised, or it is being initialised. Give a default dpi
+    return 100;
+}
+
 int DFontSizeManager::fontPixelSize(const QFont &font)
 {
     int px = font.pixelSize();
 
     if (px == -1) {
-        px = qRound(std::floor(((font.pointSizeF() * font.d->dpi) / 72) * 100 + 0.5) / 100);
+        // font.d->dpi <= 0 is unacceptable,this fallback is to avoid errors.
+        // TODO: Remove me if invalid font dpi was fixed
+        px = qRound(std::floor(((font.pointSizeF() * (font.d->dpi <= 0 ? d_defaultDpi() : font.d->dpi)) / 72) * 100 + 0.5) / 100);
     }
 
     return px;
