@@ -43,13 +43,14 @@
 #include "dwidgetstype.h"
 #include "dlabel.h"
 #include "dsizemode.h"
+#include "private/dtitlebarsettingsimpl.h"
+#include "dtitlebarsettings.h"
 
 DWIDGET_BEGIN_NAMESPACE
 
 #define CHANGESPLITWINDOW_VAR "_d_splitWindowOnScreen"
 #define GETSUPPORTSPLITWINDOW_VAR "_d_supportForSplittingWindow"
 
-static inline int DefaultTitlebarHeight() { return DSizeModeHelper::element(40, 50); }
 static inline int DefaultIconHeight() { return DSizeModeHelper::element(24, 32); }
 static inline int DefaultExpandButtonHeight() { return DSizeModeHelper::element(30, 48); }
 
@@ -82,6 +83,7 @@ private:
     void _q_addDefaultMenuItems();
     void _q_helpActionTriggered();
     void _q_feedbackActionTriggerd();
+    void _q_toolBarActionTriggerd();
     void _q_aboutActionTriggered();
     void _q_quitActionTriggered();
     void _q_switchThemeActionTriggered(QAction*action);
@@ -91,28 +93,35 @@ private:
     void updateTabOrder();
     void showSplitScreenWidget();
     void hideSplitScreenWidget();
-    void updateSizeBySizeMode()
+    /*SplitLeft: 1; SplitRight: 2; SplitFullScreen: 15*/
+    void changeWindowSplitedState(quint32 type);
+    bool supportSplitScreenByWM();
+    void updateTitleBarSize()
     {
         if (optionButton)
-            optionButton->setIconSize(QSize(DefaultTitlebarHeight(), DefaultTitlebarHeight()));
+            optionButton->setIconSize(QSize(titlebarHeight, titlebarHeight));
         if (minButton)
-            minButton->setIconSize(QSize(DefaultTitlebarHeight(), DefaultTitlebarHeight()));
+            minButton->setIconSize(QSize(titlebarHeight, titlebarHeight));
         if (maxButton)
-            maxButton->setIconSize(QSize(DefaultTitlebarHeight(), DefaultTitlebarHeight()));
+            maxButton->setIconSize(QSize(titlebarHeight, titlebarHeight));
         if (closeButton)
-            closeButton->setIconSize(QSize(DefaultTitlebarHeight(), DefaultTitlebarHeight()));
+            closeButton->setIconSize(QSize(titlebarHeight, titlebarHeight));
         if (quitFullButton)
-            quitFullButton->setIconSize(QSize(DefaultTitlebarHeight(), DefaultTitlebarHeight()));
+            quitFullButton->setIconSize(QSize(titlebarHeight, titlebarHeight));
         if (expandButton)
             expandButton->setIconSize(QSize(DefaultExpandButtonHeight(), DefaultExpandButtonHeight()));
         if (iconLabel)
             iconLabel->setIconSize(QSize(DefaultIconHeight(), DefaultIconHeight()));
 
         D_Q(DTitlebar);
-        q->setFixedHeight(DefaultTitlebarHeight());
-        q->setMinimumHeight(DefaultTitlebarHeight());
+        q->setFixedHeight(titlebarHeight);
+        q->setMinimumHeight(titlebarHeight);
     }
 
+    void setFixedButtonsEnabled(bool isEnabled);
+
+    void updateTitlebarHeight();
+
     QHBoxLayout         *mainLayout;
     QWidget             *leftArea;
     QHBoxLayout         *leftLayout;
@@ -134,14 +143,18 @@ private:
     DHorizontalLine     *separator;
 
     DBlurEffectWidget   *blurWidget = nullptr;
-    QPointer<DSplitScreenWidget> splitWidget = nullptr;
+    QPointer<DSplitScreenWidget>  splitWidget = nullptr;
     DSidebarHelper      *sidebarHelper = nullptr;
     DIconButton         *expandButton = nullptr;
 
+    int                 titlebarHeight = 50;
+    DConfig             *uiPreferDonfig = nullptr;
+
 #ifndef QT_NO_MENU
     QMenu               *menu             = Q_NULLPTR;
     QAction             *helpAction       = Q_NULLPTR;
     QAction             *feedbackAction   = Q_NULLPTR;
+    QAction             *toolbarAction    = Q_NULLPTR;
     QAction             *aboutAction      = Q_NULLPTR;
     QAction             *quitAction       = Q_NULLPTR;
     bool                canSwitchTheme    = true;
@@ -162,9 +175,217 @@ private:
     bool                splitScreenWidgetEnable = true;
     QTimer              *maxButtonPressAndHoldTimer = nullptr;
     QWidget             *sidebarBackgroundWidget = nullptr;
+    DTitlebarSettingsImpl *titlebarSettingsImpl = nullptr;
+    DTitlebarSettings *titlebarSettings = nullptr;
     Q_DECLARE_PUBLIC(DTitlebar)
 };
 
+DSplitScreenButton::DSplitScreenButton(DStyle::StandardPixmap sp, QWidget *parent)
+    : DIconButton(sp, parent)
+{
+    this->setIconSize(QSize(36, 36));
+
+    auto dpal = DPaletteHelper::instance()->palette(this);
+    dpal.setColor(DPalette::FrameBorder, Qt::transparent);
+    DPaletteHelper::instance()->setPalette(this, dpal);
+}
+
+void DSplitScreenButton::initStyleOption(DStyleOptionButton *option) const
+{
+    DIconButton::initStyleOption(option);
+
+    bool hover = (option->state & QStyle::State_MouseOver);
+    bool selected = (option->state & QStyle::State_Sunken);
+
+    if (hover && !selected) {
+        // 调整背景色和图标调色板
+        auto pal = option->palette;
+        auto dpal = DPaletteHelper::instance()->palette(this);
+        QColor backgroundBrush = dpal.itemBackground().color();
+        QColor iconForeColor = Qt::white;
+        if (DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::LightType) {
+            backgroundBrush = DStyle::adjustColor(backgroundBrush, 0, 0, 0, 0, 0, 0, 3);
+            iconForeColor = dpal.brush(DPalette::TextTitle).color();
+
+        }
+
+        pal.setBrush(QPalette::Light, backgroundBrush);
+        pal.setBrush(QPalette::Dark, backgroundBrush);
+        pal.setBrush(QPalette::ButtonText, iconForeColor);
+
+        option->palette = pal;
+    } else if (!hover && !selected) {
+        option->features |= (QStyleOptionButton::Flat | QStyleOptionButton::ButtonFeature(DStyleOptionButton::TitleBarButton));
+    }
+}
+
+DSplitScreenWidget::DSplitScreenWidget(FloatMode mode, QWidget *parent)
+    : DArrowRectangle(ArrowTop, mode, parent)
+    , floatMode(mode)
+{
+    this->init();
+}
+
+void DSplitScreenWidget::hide()
+{
+    if (!hideTimer.isActive())
+        hideTimer.start(300, this);
+}
+
+void DSplitScreenWidget::hideImmediately()
+{
+    close();
+}
+
+void DSplitScreenWidget::updateMaximizeButtonIcon(bool isMaximized)
+{
+    if (isMaximized) {
+        this->maximizeButton->setIcon(DStyle::SP_Title_SS_ShowNormalButton);
+        this->maximizeButton->setToolTip(qApp->translate("DSplitScreenWidget", "Unmaximize"));
+    } else {
+        this->maximizeButton->setIcon(DStyle::SP_Title_SS_ShowMaximizeButton);
+        this->maximizeButton->setToolTip(qApp->translate("DSplitScreenWidget", "Maximize"));
+    }
+}
+
+void DSplitScreenWidget::setButtonsEnable(bool enable)
+{
+    this->maximizeButton->setEnabled(enable);
+    this->leftSplitButton->setEnabled(enable);
+    this->rightSplitButton->setEnabled(enable);
+}
+
+void DSplitScreenWidget::onThemeTypeChanged(DGuiApplicationHelper::ColorType ct)
+{
+    if (ct == DGuiApplicationHelper::DarkType) {
+        this->setBackgroundColor(QColor(25, 25, 25, qRound(0.8 * 255)));
+    } else {
+        this->setBackgroundColor(this->palette().window().color());
+    }
+}
+
+void DSplitScreenWidget::init()
+{
+    this->setAttribute(Qt::WA_DeleteOnClose);
+    this->setWindowFlag(Qt::ToolTip);
+    this->setMargin(10);
+    this->setShadowXOffset(0);
+    this->setShadowYOffset(6);
+    this->setShadowBlurRadius(20);
+    this->setRadius(18);
+    this->setArrowWidth(50);
+    this->setArrowHeight(30);
+    this->setRadiusArrowStyleEnable(true);
+    this->setBorderColor(QColor(0, 0, 0, qRound(0.05 * 255)));
+
+    contentWidget = new QWidget(this);
+    QHBoxLayout *contentLayout = new QHBoxLayout(contentWidget);
+
+    this->leftSplitButton = new DSplitScreenButton(DStyle::SP_Title_SS_LeftButton, this);
+    this->rightSplitButton = new DSplitScreenButton(DStyle::SP_Title_SS_RightButton, this);
+    this->maximizeButton = new DSplitScreenButton(DStyle::SP_Title_SS_ShowNormalButton, this);
+    this->leftSplitButton->setToolTip(qApp->translate("DSplitScreenWidget", "Tile window to left of screen"));
+    this->rightSplitButton->setToolTip(qApp->translate("DSplitScreenWidget", "Tile window to right of screen"));
+
+    contentLayout->setMargin(0);
+    contentLayout->setSpacing(10);
+    contentLayout->addWidget(this->leftSplitButton);
+    contentLayout->addWidget(this->rightSplitButton);
+    contentLayout->addWidget(this->maximizeButton);
+
+    this->setContent(contentWidget);
+    onThemeTypeChanged(DGuiApplicationHelper::instance()->themeType());
+    qApp->installEventFilter(this);
+
+    disabledByScreenGeometryAndWindowSize({leftSplitButton, rightSplitButton});
+
+    QObject::connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged, this, &DSplitScreenWidget::onThemeTypeChanged);
+    QObject::connect(this->leftSplitButton, &DSplitScreenButton::clicked, this, &DSplitScreenWidget::leftSplitScreenButtonClicked);
+    QObject::connect(this->rightSplitButton, &DSplitScreenButton::clicked, this, &DSplitScreenWidget::rightSplitScreenButtonClicked);
+    QObject::connect(this->maximizeButton, &DSplitScreenButton::clicked, this, &DSplitScreenWidget::maximizeButtonClicked);
+}
+
+void DSplitScreenWidget::disabledByScreenGeometryAndWindowSize(QWidgetList wList)
+{
+    QDesktopWidget *desktop = qApp->desktop();
+    QWidget *window = this->window();
+
+    if (Q_LIKELY(desktop) && Q_LIKELY(window)) {
+        QRect screenRect = desktop->screenGeometry(window);
+
+        // 窗口尺寸大于屏幕分辨率时 禁用控件
+        if (screenRect.width() < window->minimumWidth() || screenRect.height() < window->minimumHeight())
+            for (QWidget *w : wList)
+                w->setDisabled(true);
+    }
+}
+
+bool DSplitScreenWidget::eventFilter(QObject *o, QEvent *e)
+{
+    switch (e->type()) {
+    case QEvent::Enter:
+        if (o == this)
+            hideTimer.stop();
+        break;
+
+    case QEvent::Leave:
+        if (o == this)
+            hide();
+        break;
+
+    case QEvent::Close:
+        if (!o->objectName().compare(QLatin1String("qtooltip_label")))
+            break;
+
+        Q_FALLTHROUGH();
+    case QEvent::WindowActivate:
+    case QEvent::WindowDeactivate:
+    case QEvent::FocusIn:
+    case QEvent::FocusOut:
+    case QEvent::MouseButtonDblClick:
+    case QEvent::Wheel:
+        hideImmediately();
+        break;
+    case QEvent::MouseButtonRelease:
+        if (!isMaxButtonPressAndHold) {
+            hideImmediately();
+        }
+        break;
+    default:
+        break;
+    }
+
+    return false;
+}
+
+void DSplitScreenWidget::showEvent(QShowEvent *e)
+{
+    this->setContent(contentWidget);
+    DArrowRectangle::showEvent(e);
+
+    QRect rect = this->rect();
+    qreal delta = this->shadowBlurRadius();
+    int arrowSpacing = (DArrowRectangle::FloatWidget == floatMode) ? this->arrowWidth() / 2 : this->arrowWidth();
+
+    if (DApplication::isDXcbPlatform())
+        rect = rect.marginsRemoved(QMarginsF(delta, (DArrowRectangle::FloatWidget == floatMode) ? 0 : delta,
+                                             delta, delta - this->margin()).toMargins());
+    else
+        rect = rect.marginsRemoved(QMarginsF(delta, 0, delta, (DArrowRectangle::FloatWidget == floatMode)
+                                             ? delta - this->margin() : delta * 2).toMargins());
+
+
+    this->setArrowX(rect.width() / 2 + arrowSpacing);
+}
+
+void DSplitScreenWidget::timerEvent(QTimerEvent *e)
+{
+    if (e->timerId() == hideTimer.timerId()) {
+        hideTimer.stop();
+        hideImmediately();
+    }
+}
+
 DTitlebarPrivate::DTitlebarPrivate(DTitlebar *qq)
     : DObjectPrivate(qq)
     , quitFullButton(nullptr)
@@ -200,6 +421,9 @@ void DTitlebarPrivate::init()
     bool isUpdated = config->value("featureUpdated", false).toBool();
     DStyle::setRedPointVisible(optionButton, isUpdated);
 
+    uiPreferDonfig = new DConfig("org.deepin.dtk.ui.preference", "", q);
+    updateTitlebarHeight();
+
     separatorTop    = new DHorizontalLine(q);
     separator       = new DHorizontalLine(q);
     titleLabel      = centerArea;
@@ -320,6 +544,12 @@ void DTitlebarPrivate::init()
             }
         });
     }
+    q->connect(uiPreferDonfig, &DConfig::valueChanged, q, [this](const QString &key){
+        if (key == "titlebarHeight") {
+            updateTitlebarHeight();
+            updateTitleBarSize();
+        }
+    });
 
     // 默认需要构造一个空的选项菜单
     q->setMenu(new QMenu(q));
@@ -339,7 +569,7 @@ void DTitlebarPrivate::init()
     // fix wayland 下显示了两个应用图标，系统标题栏 和 dtk标题栏 均显示应用图标
     q->setEmbedMode(!(DApplication::isDXcbPlatform()|| noTitlebarEnabled()));
 
-    updateSizeBySizeMode();
+    updateTitleBarSize();
 }
 
 QWidget *DTitlebarPrivate::targetWindow()
@@ -543,6 +773,9 @@ void DTitlebarPrivate::_q_toggleWindowState()
                && (maxButton->isVisible())) {
         parentWindow->showMaximized();
     }
+
+    if (splitWidget)
+        splitWidget->updateMaximizeButtonIcon(parentWindow->isMaximized());
 }
 
 void DTitlebarPrivate::_q_showMinimized()
@@ -657,6 +890,14 @@ void DTitlebarPrivate::_q_addDefaultMenuItems()
         menu->addAction(feedbackAction);
     }
 
+    // add toolbarAction menu item for deepin or uos application
+    if (titlebarSettingsImpl && titlebarSettingsImpl->isValid() && !toolbarAction) {
+        toolbarAction = new QAction(qApp->translate("TitleBarMenu", "Custom toolbar"), menu);
+        toolbarAction->setObjectName("TitlebarSettings");
+        QObject::connect(toolbarAction, SIGNAL(triggered(bool)), q, SLOT(_q_toolBarActionTriggerd()));
+        menu->addAction(toolbarAction);
+    }
+
     // add about menu item.
     if (!aboutAction) {
         aboutAction = new QAction(qApp->translate("TitleBarMenu", "About"), menu);
@@ -686,6 +927,25 @@ void DTitlebarPrivate::_q_feedbackActionTriggerd() {
     QProcess::startDetached("deepin-feedback", { qApp->applicationName() });
 }
 
+void DTitlebarPrivate::_q_toolBarActionTriggerd()
+{
+    D_Q(DTitlebar);
+
+    auto toolBarEditPanel = titlebarSettingsImpl->toolsEditPanel();
+    if (toolBarEditPanel->minimumWidth() >= q->width()) {
+        toolBarEditPanel->setParent(nullptr);
+        int x = q->mapToGlobal(q->pos()).x() - (toolBarEditPanel->width()- q->width()) / 2 ;
+        toolBarEditPanel->move(x, q->mapToGlobal(q->pos()).y() + q->height());
+    } else {
+        toolBarEditPanel->setParent(q->parentWidget());
+        toolBarEditPanel->move(0, q->height());
+        toolBarEditPanel->resize(q->width(), q->parentWidget()->height() * 70 / 100);
+    }
+    toolBarEditPanel->installEventFilter(q);
+
+    titlebarSettingsImpl->showEditPanel();
+}
+
 void DTitlebarPrivate::_q_aboutActionTriggered()
 {
     DApplication *dapp = qobject_cast<DApplication *>(qApp);
@@ -782,16 +1042,26 @@ void DTitlebarPrivate::showSplitScreenWidget()
     }
 
     // 窗管不支持分屏时，不显示分屏菜单
-    if (!Q_LIKELY(DSplitScreenWidget::supportSplitScreenByWM(q->window())))
+    if (!Q_LIKELY(supportSplitScreenByWM()))
         return;
 
     if (!splitWidget) {
-        splitWidget = new DSplitScreenWidget(q->window());
+        splitWidget = new DSplitScreenWidget(DSplitScreenWidget::FloatWidget, q->window());
+
+        QObject::connect(splitWidget, &DSplitScreenWidget::maximizeButtonClicked, q,
+                         std::bind(&DTitlebarPrivate::changeWindowSplitedState, this, DSplitScreenWidget::SplitFullScreen));
+        QObject::connect(splitWidget, &DSplitScreenWidget::leftSplitScreenButtonClicked, q,
+                         std::bind(&DTitlebarPrivate::changeWindowSplitedState, this, DSplitScreenWidget::SplitLeftHalf));
+        QObject::connect(splitWidget, &DSplitScreenWidget::rightSplitScreenButtonClicked, q,
+                         std::bind(&DTitlebarPrivate::changeWindowSplitedState, this, DSplitScreenWidget::SplitRightHalf));
     }
 
     if (splitWidget->isVisible())
         return;
 
+    if (auto window = targetWindow())
+        splitWidget->updateMaximizeButtonIcon(window->isMaximized());
+
     auto centerPos = maxButton->mapToGlobal(maxButton->rect().center());
     auto bottomPos = maxButton->mapToGlobal(maxButton->rect().bottomLeft());
 
@@ -803,9 +1073,11 @@ void DTitlebarPrivate::showSplitScreenWidget()
     }
 
     if (bottomPos.y() + splitWidget->height() > rect.height()) {
-        splitWidget->show(QPoint(centerPos.x() - splitWidget->width() / 2, bottomPos.y() - maxButton->rect().height() - splitWidget->height()));
+        splitWidget->setArrowDirection(DArrowRectangle::ArrowBottom);
+        splitWidget->show(centerPos.x() - splitWidget->arrowWidth() / 2, bottomPos.y() - maxButton->rect().height());
     } else {
-        splitWidget->show(QPoint(centerPos.x() - splitWidget->width() / 2, bottomPos.y()));
+        splitWidget->setArrowDirection(DArrowRectangle::ArrowTop);
+        splitWidget->show(centerPos.x() - splitWidget->arrowWidth() / 2, bottomPos.y());
     }
 }
 
@@ -820,8 +1092,67 @@ void DTitlebarPrivate::hideSplitScreenWidget()
     splitWidget->hide();
 }
 
+void DTitlebarPrivate::changeWindowSplitedState(quint32 type)
+{
+    if (splitWidget && splitWidget->isVisible()) {
+        splitWidget->isMaxButtonPressAndHold = false;
+        splitWidget->hideImmediately();
+    }
+    D_Q(DTitlebar);
+    QFunctionPointer splitWindowOnScreen = Q_NULLPTR;
+
+    //### 目前接口尚不公开在 dtkgui 中，等待获取后续接口稳定再做移植
+    splitWindowOnScreen = qApp->platformFunction(CHANGESPLITWINDOW_VAR);
+
+    const QWindow *windowHandle = nullptr;
+    const QWidget *window = q->window();
+
+    if (window)
+        windowHandle  = window->windowHandle();
+
+    if (splitWindowOnScreen && windowHandle && windowHandle->handle())
+        reinterpret_cast<void(*)(quint32, quint32)>(splitWindowOnScreen)(windowHandle->handle()->winId(), type);
+}
+
+bool DTitlebarPrivate::supportSplitScreenByWM()
+{
+    //### 目前接口尚不公开在 dtkgui 中，等待获取后续接口稳定再做移植
+    D_Q(DTitlebar);
+    QFunctionPointer getSupportSplitWindow = Q_NULLPTR;
+    bool supported = false;
+
+    getSupportSplitWindow = qApp->platformFunction(GETSUPPORTSPLITWINDOW_VAR);
+
+    const QWindow *windowHandle = nullptr;
+    const QWidget *window = q->window();
+
+    if (window)
+        windowHandle  = window->windowHandle();
+
+    if (getSupportSplitWindow && windowHandle && windowHandle->handle())
+        supported = reinterpret_cast<bool(*)(quint32)>(getSupportSplitWindow)(windowHandle->handle()->winId());
+
+    return supported;
+}
+
 #endif
 
+void DTitlebarPrivate::setFixedButtonsEnabled(bool isEnabled)
+{
+    maxButton->setEnabled(isEnabled);
+    minButton->setEnabled(isEnabled);
+    closeButton->setEnabled(isEnabled);
+    optionButton->setEnabled(isEnabled);
+}
+
+void DTitlebarPrivate::updateTitlebarHeight()
+{
+    titlebarHeight = uiPreferDonfig->value("titlebarHeight").toInt();
+    // 配置项默认值是-1，从配置读取进来的值超出0-100的范围，通过模式获取值，否则使用获取的配置值
+    if (titlebarHeight <= 0 || titlebarHeight > 100)
+        titlebarHeight = DSizeModeHelper::element(40, 50);
+}
+
 /*!
   @~english
   \class Dtk::Widget::DTitlebar
@@ -1073,6 +1404,13 @@ bool DTitlebar::eventFilter(QObject *obj, QEvent *event)
 
         }
     }
+    if (d->titlebarSettings && d->titlebarSettingsImpl->hasEditPanel() && obj == d->titlebarSettingsImpl->toolsEditPanel()) {
+        if (event->type() == QEvent::Show) {
+            d->setFixedButtonsEnabled(false);
+        } else if ((event->type() == QEvent::Close)) {
+            d->setFixedButtonsEnabled(true);
+        }
+    }
     return QWidget::eventFilter(obj, event);
 }
 
@@ -1093,7 +1431,8 @@ bool DTitlebar::event(QEvent *e)
         }
     } else if (e->type() == QEvent::StyleChange) {
         D_D(DTitlebar);
-        d->updateSizeBySizeMode();
+        d->updateTitlebarHeight();
+        d->updateTitleBarSize();
     }
 
     return QFrame::event(e);
@@ -1117,6 +1456,20 @@ void DTitlebar::resizeEvent(QResizeEvent *event)
     if (d->sidebarBackgroundWidget)
         d->sidebarBackgroundWidget->setFixedHeight(event->size().height());
 
+    if (d->titlebarSettingsImpl && d->titlebarSettingsImpl->hasEditPanel() && d->titlebarSettingsImpl->toolsEditPanel()->isVisible()) {
+        if (d->titlebarSettingsImpl->toolsEditPanel()->minimumWidth() >= this->width()) {
+            d->titlebarSettingsImpl->toolsEditPanel()->setWindowFlag(Qt::Dialog);
+            d->titlebarSettingsImpl->toolsEditPanel()->show();
+            int x = this->mapToGlobal(this->pos()).x() - (d->titlebarSettingsImpl->toolsEditPanel()->width()- this->width()) / 2 ;
+            d->titlebarSettingsImpl->toolsEditPanel()->move(x, this->mapToGlobal(this->pos()).y() + this->height());
+        } else {
+            d->titlebarSettingsImpl->toolsEditPanel()->setWindowFlag(Qt::Dialog, false);
+            d->titlebarSettingsImpl->toolsEditPanel()->show();
+            d->titlebarSettingsImpl->toolsEditPanel()->move(0, this->height());
+            d->titlebarSettingsImpl->toolsEditPanel()->resize(width(), parentWidget()->height() * 70 / 100);
+        }
+    }
+
     return QWidget::resizeEvent(event);
 }
 
@@ -1193,28 +1546,20 @@ void DTitlebar::setSidebarHelper(DSidebarHelper *helper)
         d->sidebarBackgroundWidget->lower();
         d->leftLayout->addWidget(d->expandButton, 0, Qt::AlignLeft);
         connect(d->expandButton, &DIconButton::clicked, [this, d] (bool isExpanded) {
-            d->sidebarBackgroundWidget->setVisible(isExpanded);
             d->sidebarHelper->setExpanded(isExpanded);
             int x = isExpanded ? d->sidebarHelper->width() : 0;
             d->separator->move(x, height() - d->separator->height());
         });
-        connect(d->sidebarHelper, &DSidebarHelper::widthChanged, this, [d] (int width) {
-            d->sidebarBackgroundWidget->setFixedWidth(width);
-        });
     }
 
     connect(helper, &DSidebarHelper::visibleChanged, this, [this](bool visible){
-        qInfo() << "visibleChanged" << visible;
         d_func()->expandButton->setVisible(visible);
     });
-    connect(helper, &DSidebarHelper::expandChanged, this, [](bool expanded){
-        qInfo() << "expandChanged" << expanded;
+    connect(helper, &DSidebarHelper::expandChanged, this, [this](bool isExpanded){
+        d_func()->sidebarBackgroundWidget->setVisible(isExpanded);
     });
-    connect(helper, &DSidebarHelper::backgroundColorChanged, this, [](QColor backgroundColor){
-        qInfo() << "backgroundColorChanged" << backgroundColor.name(QColor::NameFormat::HexArgb);
-    });
-    connect(helper, &DSidebarHelper::widthChanged, this, [](int width){
-        qInfo() << "widthChanged" << width;
+    connect(helper, &DSidebarHelper::widthChanged, this, [this](int width){
+        d_func()->sidebarBackgroundWidget->setFixedWidth(width);
     });
 
 }
@@ -1615,7 +1960,7 @@ QSize DTitlebar::sizeHint() const
     int padding = qMax(d->leftArea->sizeHint().width(), d->rightArea->sizeHint().width());
     int width = d->centerArea->sizeHint().width() + 2 * d->mainLayout->spacing() + 2 * padding;
 
-    return QSize(width, DefaultTitlebarHeight());
+    return QSize(width, d->titlebarHeight);
 }
 
 QSize DTitlebar::minimumSizeHint() const
@@ -1635,6 +1980,18 @@ void DTitlebar::setFullScreenButtonVisible(bool visible)
     d->fullScreenButtonVisible = visible;
 }
 
+DTitlebarSettings *DTitlebar::settings()
+{
+    D_D(DTitlebar);
+
+    if (!d->titlebarSettings) {
+        auto settings = new DTitlebarSettings(this);
+        d->titlebarSettingsImpl = settings->impl();
+        d->titlebarSettings = settings;
+    }
+    return d->titlebarSettings;
+}
+
 void DTitlebar::mouseMoveEvent(QMouseEvent *event)
 {
     D_D(DTitlebar);
