@@ -20,6 +20,7 @@ protected:
     void paintEvent(QPaintEvent *e) override;
 };
 
+class DLicenseDialog;
 class DAboutDialogPrivate : public DDialogPrivate
 {
 public:
@@ -28,10 +29,9 @@ public:
     void init();
     void loadDistributionInfo();
     void updateWebsiteLabel();
-    void updateAcknowledgementLabel();
     void _q_onLinkActivated(const QString &link);
     void _q_onFeatureActivated(const QString &link);
-
+    void _q_onLicenseActivated(const QString &link);
     QPixmap loadPixmap(const QString &file);
 
     static const QString websiteLinkTemplate;
@@ -44,13 +44,15 @@ public:
     QLabel *licenseLabel = nullptr;
     QLabel *companyLogoLabel = nullptr;
     QLabel *websiteLabel = nullptr;
-    QLabel *acknowledgementLabel = nullptr;
     QLabel *featureLabel = nullptr;
     DRedPointLabel *redPointLabel = nullptr;
+    QLabel *acknowledgementLabel = nullptr;
+    QLabel *acknowledgementTipLabel = nullptr;
+    DLicenseDialog *licenseDialog = Q_NULLPTR;
+
     QString logoPath;
     QString websiteName;
     QString websiteLink;
-    QString acknowledgementLink;
     Q_DECLARE_PUBLIC(DAboutDialog)
 };
 
